summaryrefslogtreecommitdiffstats
path: root/kstyles/web
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-03 23:01:18 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-03 23:01:18 -0600
commitaa3abfa2a78cccfcb1f91d808753c79295d618e9 (patch)
treefe00218b08a670818d7ee67e677d1f6b5ded6eed /kstyles/web
parente92a4e05c504978308b2dd83082d2727b74bea8f (diff)
downloadtdelibs-aa3abfa2a78cccfcb1f91d808753c79295d618e9.tar.gz
tdelibs-aa3abfa2a78cccfcb1f91d808753c79295d618e9.zip
Rename KStyle to TDEStyle to avoid conflicts with KDE4
Diffstat (limited to 'kstyles/web')
-rw-r--r--kstyles/web/plugin.cpp2
-rw-r--r--kstyles/web/webstyle.cpp10
-rw-r--r--kstyles/web/webstyle.h2
3 files changed, 7 insertions, 7 deletions
diff --git a/kstyles/web/plugin.cpp b/kstyles/web/plugin.cpp
index c22bb08fa..6ab10ebd8 100644
--- a/kstyles/web/plugin.cpp
+++ b/kstyles/web/plugin.cpp
@@ -3,7 +3,7 @@
extern "C"
{
- KStyle * allocate() { return new WebStyle; }
+ TDEStyle * allocate() { return new WebStyle; }
int minor_version() { return 0; }
int major_version() { return 1; }
const char * description() { return(i18n("Web style plugin").utf8()); }
diff --git a/kstyles/web/webstyle.h b/kstyles/web/webstyle.h
index 611cf8485..68f83c99b 100644
--- a/kstyles/web/webstyle.h
+++ b/kstyles/web/webstyle.h
@@ -28,7 +28,7 @@ class TQScrollBar;
class TQPushButton;
class TQWidget;
-class WebStyle : public KStyle
+class WebStyle : public TDEStyle
{
public:
diff --git a/kstyles/web/webstyle.cpp b/kstyles/web/webstyle.cpp
index 3e850394f..aca43fb74 100644
--- a/kstyles/web/webstyle.cpp
+++ b/kstyles/web/webstyle.cpp
@@ -218,7 +218,7 @@ drawFunkyRect
}
WebStyle::WebStyle()
- : KStyle()
+ : TDEStyle()
{
setButtonDefaultIndicatorWidth(6);
setScrollBarExtent(_scrollBarExtent, _scrollBarExtent);
@@ -423,7 +423,7 @@ WebStyle::drawPushButtonLabel(TQPushButton * b, TQPainter * p)
{
// This is complicated stuff and we don't really want to mess with it.
- KStyle::drawPushButtonLabel(b, p);
+ TDEStyle::drawPushButtonLabel(b, p);
}
void
@@ -474,7 +474,7 @@ WebStyle::drawScrollBarControls
Qt::ArrowType t =
sb->orientation() == Horizontal ? Qt::RightArrow : Qt::DownArrow;
// Is it me or is KStyle::drawArrow broken ?
drawArrow
(
@@ -930,7 +930,7 @@ WebStyle::drawArrow
const TQBrush * fill
)
{
- KStyle::drawArrow(p, type, down, x, y, w, h, g, enabled, fill);
+ TDEStyle::drawArrow(p, type, down, x, y, w, h, g, enabled, fill);
}
void
@@ -1308,7 +1308,7 @@ WebStyle::drawPopupMenuItem
)
{
// TODO
- KStyle::drawPopupMenuItem(p, checkable, maxpmw, tab, mi, pal, act, enabled, x, y, w, h);
+ TDEStyle::drawPopupMenuItem(p, checkable, maxpmw, tab, mi, pal, act, enabled, x, y, w, h);
}
void
@@ -474,7 +474,7 @@ WebStyle::drawScrollBarControls
Qt::ArrowType t =
sb->orientation() == Horizontal ? Qt::RightArrow : Qt::DownArrow;
- // Is it me or is KStyle::drawArrow broken ?
+ // Is it me or is TDEStyle::drawArrow broken ?
drawArrow
(